@@ -9,7 +9,7 @@ from pydantic import AnyHttpUrl, BaseModel, parse_obj_as, validator
 import requests
 
 from . import get_logger
-from .consts import VERSION_REGEX, known_instances
+from .consts import RETRY_STATUSES, VERSION_REGEX, known_instances
 from .dandiapi import BaseRemoteAsset, DandiAPIClient, RemoteDandiset
 from .exceptions import FailedToConnectError, NotFoundError, UnknownURLError
 from .utils import get_instance
@@ -526,13 +526,12 @@ class _dandi_url_parser:
         i = 0
         while True:
             r = requests.head(url, allow_redirects=True)
-            if r.status_code == 404:
-                if i < 3:
-                    sleep(0.1 * 10 ** i)
-                    i += 1
-                    continue
-                else:
-                    raise NotFoundError(url)
+            if r.status_code in (400, *RETRY_STATUSES) and i < 5:
+                sleep(0.1 * 10 ** i)
+                i += 1
+                continue
+            elif r.status_code == 404:
+                raise NotFoundError(url)
             elif r.status_code != 200:
                 raise FailedToConnectError(
                     f"Response for getting {url} to redirect returned {r.status_code}."
